#!/bin/bash

# initial setup of the neural network of pisces 1D. This is run once, at the start of the experiment.

# 1. Makes EXPID directory and copy all the content from EXP00 into a default folder (.xml, executable, namelists)
# 2. Reads the inputted latitude and longitude and makes 3*3 cropped netcdf files from the inputs, and places them in
#    a new directory
# 3. Run the simulation with the default parameters
# 4. Obtaining the bias between the model in default settings and the observed data, to be used as a reference for the
#    other simulations
# 5. Generates an array of randomly assigned parameters as an initial set and saves as a .csv file

mode=default  # observed or default
restart=F     # T or F. T = restart a stopped experiment; F = start a new one
crop=False


## EDIT HERE TO CHANGE THE LOCATION OF THE 1DPISCES
## DEFAULT: LAT=56, LON=-49 (LABRADOR SEA)
LAT=56
LON=-49

SCRHOME=/gpfs/scratch/bsc32/bsc32786/                                             # base directory of the nemo model
MODEL=${SCRHOME}%EXPID%/EXP00/                                                    # path that will be created and the experiment stored
INPUTS=/gpfs/projects/bsc32/repository/pisces_off/ORCA1_OFF_PISCES_83138_2015/
#INPUTS=/gpfs/projects/bsc32/repository/pisces_off/ORCA1_OFF_PISCES_83858_2014/ 
#INPUTS=/gpfs/projects/bsc32/repository/pisces_off/ORCA1_OFF_PISCES_83705_2014/
#INPUTS=/gpfs/projects/bsc32/repository/pisces_off/ORCA1_OFF_PISCES_66496_2013/    # path to input (netCDF) files (PATH ONLY)
#INPUTS=/gpfs/projects/bsc32/repository/pisces_off/current/
NEMO=/gpfs/projects/bsc32/models/pisces_off/gapoc/cfgs/mP1D/EXP00/                # path to .xml, executable, and namelist files (PATH ONLY)
MODELFILE=PISCES_5d_19600101_19641231_ptrc_T.nc                                   # name of output file (FILE ONLY)
PARAMETERS=/gpfs/scratch/bsc32/bsc32786/pisces1d/parameters/sobolSeq_N_2000_P_11_2021-11-08.csv

### 1. MAKE EXPID DIRECTORY AND COPY ALL THE CONTENT FROM EXP00 INTO A DEFAULT FOLDER (.XML, EXECUTABLES, AND NAMELISTS)

mkdir -p ${MODEL}
cd ${MODEL}

rm -rf *

mkdir -p default
cd default
cp -R ${NEMO}nemo .
cp -R ${NEMO}namelist* .
cp -R ${NEMO}*.xml .

# 2. makes a new directory, crops the netcdf files and puts them there. If it already exists, it is replaced


cd ${MODEL}
mkdir -p ./cropped
cp -R ${INPUTS}* ${MODEL}default
cp -R ${INPUTS}* ${MODEL}cropped


### 3.  run the simulation with the default parameters
module purge
module load intel/2017.4
module load impi/2018.4
module load netcdf/4.2
module load hdf5/1.8.19
module load perl

cd ${MODEL}default

mpirun -np 1 ./nemo

