#!/bin/bash

# simulation part of the neural network. This is run by individual chunks in parallel with each other

### 1. Creates directories for each member if they havent already done so, i.e. in the first generation
### 2. Edits the namelists of each member using the corresponding row of the 00.csv parameters file
### 3. Runs the simulation
### 4. Uses the outputs, reference bias and observed data to collect the cost and save as a .txt

mode=default

## ALL SHOULD BE THE SAME AS THOSE IN pre.sh
SCRHOME=/gpfs/scratch/bsc32/bsc32786/
MODEL=${SCRHOME}%EXPID%/EXP00/
MODELFILE=PISCES_5d_19600101_19641231_ptrc_T.nc
PARAMETERS=/gpfs/scratch/bsc32/bsc32786/pisces1d/parameters/sobolSeq_N_2000_P_11_2021-11-08.csv
NEMO=/gpfs/projects/bsc32/models/pisces_off/gapoc/cfgs/mP1D/EXP00/

if [ $mode = 'observed' ]
then
    # path to the observed data. (PATH AND FILE) MUST BE ON THE SAME GRID AS THE MODEL
    OBS=${SCRHOME}pisces1d/obs/current

elif [ $mode = 'default' ]
then
    OBS=${SCRHOME}%EXPID%/EXP00/default/$MODELFILE
fi

### 1. Creates directories for each member if they havent already done so, i.e. in the first generation

shopt -s nullglob

#chunk=%CHUNK%
#printf -v chunk "%04d" $chunk

chunk=%CHUNK%
member=%MEMBER%

#let "row = ($chunk - 1) * 100 + ${member:4:2}"
#printf -v row "%04d" $row

let "chunk = $chunk-1" || true
printf -v chunk "%02d" $chunk
member=${member:4:2}
row=$chunk$member

cd ${MODEL}
if [ ! -d $row ]; then
    # MAKE EXPID DIRECTORY AND COPY ALL THE CONTENT FROM EXP00 (.XML, EXECUTABLES, AND NAMELISTS)
    mkdir -p $row
else
    rm $row/*
fi
cd $row
cp -R ${NEMO}nemo .
cp -R ${NEMO}namelist* .
cp -R ${NEMO}*.xml .
cp -R ${MODEL}cropped/* .

### 2. Edits the namelists of each member using the corresponding row of the 0000.csv parameters file

NAMELIST=namelist_pisces_cfg

#cd ${MODEL}$chunk/

module load python

function changenls {

nls="$(python - $1 $2 $3 << END
# inputs:
# 1. Parameters file (0000.csv)
# 2. Namelist (namelist_pisces_ref)
# 4. Chunk number

import os
import pandas as pd
import numpy as np

names=pd.read_csv('$1')

row='$3'

with open('$2','r') as nl:
    with open('temp','w+') as t:
        lines=nl.readlines()
        lines = [i[:-1] for i in lines]
        for l in lines:
            for j in range(len(names.keys())):
                lstart=l
                lcomm=''
                if '!' in l:
                    lstart=l[:l.find('!')] # so that comments that contain the variable name don't get edited
                    lcomm=l[l.find('!'):]# + '\n'
                if ' ' + names.keys()[j]+' ' in lstart and "=" in lstart:
                    lstart = '   '+ names.keys()[j] + '  =  ' + str(names.iloc[[row]].values[0][j]) + ' '
                    break
            t.write(lstart + lcomm + '\n')

os.remove('$2')
os.rename('temp','$2')

new = pd.DataFrame(data = names.iloc[[row]].values, columns = names.keys(), index = [row])
new.to_csv(str(row)+'_params.csv')

END
)"
}

changenls ${PARAMETERS} ${MODEL}$row/$NAMELIST $row


### 3. Runs the simulation

cd ${MODEL}$row

module purge
module load intel/2017.4
module load impi/2018.4
module load netcdf/4.2
module load hdf5/1.8.19
module load perl

mpirun -np 1 ./nemo